summaryrefslogtreecommitdiff
path: root/src/guichan/include
diff options
context:
space:
mode:
authorAndrei Karas <akaras@inbox.ru>2011-09-09 19:43:40 +0300
committerAndrei Karas <akaras@inbox.ru>2011-09-09 19:43:40 +0300
commit4484b433abc8f07bcf7d4d22fd946e00b66b078d (patch)
treed8d04c6ea9526b90334e7b0a4abf44e2508a3597 /src/guichan/include
parentc1fb0bf9dc98e2a30f33cbbf4f74604b36efbcba (diff)
downloadplus-4484b433abc8f07bcf7d4d22fd946e00b66b078d.tar.gz
plus-4484b433abc8f07bcf7d4d22fd946e00b66b078d.tar.bz2
plus-4484b433abc8f07bcf7d4d22fd946e00b66b078d.tar.xz
plus-4484b433abc8f07bcf7d4d22fd946e00b66b078d.zip
Fix first part of shadow variables/methods errors.
Diffstat (limited to 'src/guichan/include')
-rw-r--r--src/guichan/include/guichan/cliprectangle.hpp32
-rw-r--r--src/guichan/include/guichan/inputevent.hpp8
-rw-r--r--src/guichan/include/guichan/keyevent.hpp20
-rw-r--r--src/guichan/include/guichan/mouseevent.hpp16
4 files changed, 38 insertions, 38 deletions
diff --git a/src/guichan/include/guichan/inputevent.hpp b/src/guichan/include/guichan/inputevent.hpp
index 8594d3dae..f252341cf 100644
--- a/src/guichan/include/guichan/inputevent.hpp
+++ b/src/guichan/include/guichan/inputevent.hpp
@@ -69,10 +69,10 @@ namespace gcn
* @param isMetaPressed True if meta is pressed, false otherwise.
*/
InputEvent(Widget* source,
- bool isShiftPressed,
- bool isControlPressed,
- bool isAltPressed,
- bool isMetaPressed);
+ bool shiftPressed,
+ bool controlPressed,
+ bool altPressed,
+ bool metaPressed);
/**
* Checks if shift is pressed.
diff --git a/src/guichan/include/guichan/cliprectangle.hpp b/src/guichan/include/guichan/cliprectangle.hpp
index 792c40bb9..b5aa5e4af 100644
--- a/src/guichan/include/guichan/cliprectangle.hpp
+++ b/src/guichan/include/guichan/cliprectangle.hpp
@@ -67,23 +67,23 @@ namespace gcn
/**
* Constructor.
*
* @param x The rectangle x coordinate.
* @param y The rectangle y coordinate.
* @param width The rectangle width.
* @param height The rectangle height.
* @param xOffset The offset of the x coordinate. Used to for
* calculating the actual screen coordinate from
* the relative screen coordinate.
* @param yOffset The offset of the y coordinate. Used to for
* calculating the actual screen coordinate from
* the relative screen coordinate.
*/
- ClipRectangle(int x,
- int y,
- int width,
- int height,
- int xOffset,
- int yOffset);
+ ClipRectangle(int x0,
+ int y0,
+ int width0,
+ int height0,
+ int xOffset0,
+ int yOffset0);
/**
* Copy constructor. Copies x, y, width and height
@@ -67,23 +67,23 @@ namespace gcn
* Constructor.
*
- * @param x The rectangle x coordinate.
- * @param y The rectangle y coordinate.
- * @param width The rectangle width.
- * @param height The rectangle height.
- * @param xOffset The offset of the x coordinate. Used to for
- * calculating the actual screen coordinate from
- * the relative screen coordinate.
- * @param yOffset The offset of the y coordinate. Used to for
- * calculating the actual screen coordinate from
- * the relative screen coordinate.
+ * @param x0 The rectangle x coordinate.
+ * @param y0 The rectangle y coordinate.
+ * @param width0 The rectangle width.
+ * @param height0 The rectangle height.
+ * @param xOffset0 The offset of the x coordinate. Used to for
+ * calculating the actual screen coordinate from
+ * the relative screen coordinate.
+ * @param yOffset0 The offset of the y coordinate. Used to for
+ * calculating the actual screen coordinate from
+ * the relative screen coordinate.
*/
diff --git a/src/guichan/include/guichan/keyevent.hpp b/src/guichan/include/guichan/keyevent.hpp
index f42601235..5c10238c5 100644
--- a/src/guichan/include/guichan/keyevent.hpp
+++ b/src/guichan/include/guichan/keyevent.hpp
@@ -71,22 +71,22 @@ namespace gcn
* Constructor.
*
* @param source The source widget of the event.
* @param isShiftPressed True if shift is pressed, false otherwise.
* @param isControlPressed True if control is pressed, false otherwise.
* @param isAltPressed True if alt is pressed, false otherwise.
* @param isMetaPressed True if meta is pressed, false otherwise.
* @param type The type of the event. A value from KeyEventType.
* @param isNumericPad True if the event occured on the numeric pad,
* false otherwise.
* @param key The key of the event.
*/
KeyEvent(Widget* source,
- bool isShiftPressed,
- bool isControlPressed,
- bool isAltPressed,
- bool isMetaPressed,
+ bool shiftPressed,
+ bool controlPressed,
+ bool altPressed,
+ bool metaPressed,
unsigned int type,
- bool isNumericPad,
+ bool numericPad,
const Key& key);
/**
@@ -71,22 +71,22 @@ namespace gcn
*
* @param source The source widget of the event.
- * @param isShiftPressed True if shift is pressed, false otherwise.
- * @param isControlPressed True if control is pressed, false otherwise.
- * @param isAltPressed True if alt is pressed, false otherwise.
- * @param isMetaPressed True if meta is pressed, false otherwise.
+ * @param shiftPressed True if shift is pressed, false otherwise.
+ * @param controlPressed True if control is pressed, false otherwise.
+ * @param altPressed True if alt is pressed, false otherwise.
+ * @param metaPressed True if meta is pressed, false otherwise.
* @param type The type of the event. A value from KeyEventType.
@@ -71,22 +71,22 @@ namespace gcn
* @param type The type of the event. A value from KeyEventType.
- * @param isNumericPad True if the event occured on the numeric pad,
+ * @param numericPad True if the event occured on the numeric pad,
* false otherwise.
* @param key The key of the event.
diff --git a/src/guichan/include/guichan/mouseevent.hpp b/src/guichan/include/guichan/mouseevent.hpp
index 280d373e6..6f6dc828c 100644
--- a/src/guichan/include/guichan/mouseevent.hpp
+++ b/src/guichan/include/guichan/mouseevent.hpp
@@ -66,10 +66,10 @@ namespace gcn
* Constructor.
*
* @param source The source widget of the mouse event.
* @param isShiftPressed True if shift is pressed, false otherwise.
* @param isControlPressed True if control is pressed, false otherwise.
* @param isAltPressed True if alt is pressed, false otherwise.
* @param isMetaPressed True if meta is pressed, false otherwise.
* @param type The type of the mouse event.
* @param button The button of the mouse event.
* @param x The x coordinate of the event relative to the source widget.
@@ -78,10 +78,10 @@ namespace gcn
* It's set to zero if another button is used.
*/
MouseEvent(Widget* source,
- bool isShiftPressed,
- bool isControlPressed,
- bool isAltPressed,
- bool isMetaPressed,
+ bool shiftPressed,
+ bool controlPressed,
+ bool altPressed,
+ bool metaPressed,
unsigned int type,
unsigned int button,
int x,
@@ -66,10 +66,10 @@ namespace gcn
*
* @param source The source widget of the mouse event.
- * @param isShiftPressed True if shift is pressed, false otherwise.
- * @param isControlPressed True if control is pressed, false otherwise.
- * @param isAltPressed True if alt is pressed, false otherwise.
- * @param isMetaPressed True if meta is pressed, false otherwise.
+ * @param shiftPressed True if shift is pressed, false otherwise.
+ * @param controlPressed True if control is pressed, false otherwise.
+ * @param altPressed True if alt is pressed, false otherwise.
+ * @param metaPressed True if meta is pressed, false otherwise.
* @param type The type of the mouse event.
* @param button The button of the mouse event.